OC.L10N.register(
    "app_api",
    {
    "Delete" : "Kkes",
    "Default" : "Prédéfini(e)",
    "Edit" : "Ẓreg",
    "Name" : "Nom",
    "Enabled" : "Yermed",
    "Confirm" : "Serggeg",
    "Save" : "Sekles",
    "Remove" : "Kkes",
    "Type" : "Anaw",
    "Details" : "Talqayt",
    "Disable" : "Désactiver"
},
"nplurals=2; plural=(n != 1);");
